<?php
defined('_JEXEC') or die;

require_once JPATH_COMPONENT_ADMINISTRATOR . '/installer/product.php';

/**
 * Class CInstallerControllerInstall
 *
 * @since  1.0.0
 */
class CInstallerControllerInstall extends JControllerLegacy
{
	/**
	 * Upload an package file
	 *
	 * @return  void
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function upload()
	{
		$input = JFactory::getApplication()->input;

		$files = $input->files;

		jimport('joomla.filesystem.file');

		// We need raw here, because else zip files are scanned...
		$file = $input->files->get('fileupload', '', 'raw');

		// Cleans the name of the file by removing weird characters
		$filename = JFile::makeSafe($file['name']);

		$allowed = array('zip');

		// File extension check
		if (!in_array(strtolower(JFile::getExt($filename)), $allowed))
		{
			echo json_encode(
				array(
					'status'        => 'error',
					'error_message' => 'Invalid file type ' . JFile::getExt($filename)
				)
			);

			jexit(42);
		}

		// Upload package to the tmp folder
		$uploadFolder = JPATH_ROOT . '/tmp';

		$src  = $file['tmp_name'];
		$dest = $uploadFolder . '/' . $filename;

		if (JFile::upload($src, $dest, false, true))
		{
			echo json_encode(array('status' => 'ok', 'filename' => $uploadFolder . '/' . $filename));
		}
		else
		{
			echo json_encode(array('status' => 'error', 'error_message' => 'Could not upload file to destination directory. Please check file permissions in the tmp folder and PHP maximum file upload size.'));
		}

		jexit(0);
	}

	/**
	 * Install and download the extension
	 *
	 * @return  void
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function install()
	{
		$input          = JFactory::getApplication()->input;
		$downloadKey    = $input->get('installation_key', '');
		$productId      = $input->getString('product', '');
		$uploadFileName = $input->getString('upload_file_name', '');

		/** @var CInstallerModelInstall $model */
		$model = JModelLegacy::getInstance('Install', 'CInstallerModel');

		$product = $model->getProduct($productId);

		header('Content-Type: application/json');

		// We need a download key if the product needs one and we have no upload file
		if ($product->needsDownloadId() && empty($downloadKey) && empty($uploadFileName))
		{
			echo json_encode(array('error' => true, 'message' => 'No Download key'));
			jexit(42);
		}

		try
		{
			// First get the download URL (validate)
			$curl = curl_init();

			$url = 'https://compojoom.com/index.php?option=com_cdomains&controller=domains&task=download';

			// Set some options - we are passing in a user agent too here
			curl_setopt_array($curl, array(
				CURLOPT_RETURNTRANSFER => 1,
				CURLOPT_URL            => $url,
				CURLOPT_USERAGENT      => 'CInstaller ' . CINSTALLER_VERSION . ' with cURL',
				CURLOPT_POST           => 1,
				CURLOPT_POSTFIELDS     => array(
					'domain'             => JUri::root(),
					'joomla_version'     => JVersion::RELEASE . JVersion::BUILD,
					'domain_key'         => $downloadKey,
					'product_category'   => $product->getArsCategory(),
					'product_identifier' => $product->identifier,
					'upload_file_name'   => $uploadFileName
				)
			));

			// Send the request & save response to $resp
			$resp = curl_exec($curl);
			$data = json_decode($resp);
		}
		catch (Exception $e)
		{
			$data = null;
		}

		if ((!$data || $data->error == true) && empty($uploadFileName))
		{
			echo json_encode(array('error' => true, 'message' => 'Error getting download, check your Download id and make sure your server supports curl!', 'response' => $data, 'rawdata' => json_encode($resp)));
			jexit(42);
		}

		if (empty($uploadFileName))
		{
			$url = 'https://compojoom.com/' . $data->download_url;

			ob_start();
			$this->downloadPackage($url);
			$result = ob_get_contents();
			ob_end_clean();
		}
		else
		{
			ob_start();
			$this->installLocalPackage($uploadFileName);
			$result = ob_get_contents();
			ob_end_clean();
		}


		if ($result == 'false')
		{
			echo json_encode(array('error' => true, 'message' => 'Error installing extension ', 'rawdata' => json_encode($result)));
			jexit(42);
		}

		echo json_encode(array('success' => 'true', 'rawdata' => json_encode($result)));

		jexit(0);
	}

	/**
	 * Install sample data and localization
	 *
	 * @return  void
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function sampledata()
	{
		$input = JFactory::getApplication()->input;

		header('Content-Type: application/json');

		$product = $input->get('product', null);

		if (empty($product))
		{
			echo json_encode(array('error' => true, 'message' => 'No product given'));
			jexit(42);
		}

		$sampleDataInstall          = $input->get('sample_data', '');
		$localizationOptionsInstall = $input->get('localization_data', '');

		// Check if there is something to install
		if (empty($sampleDataInstall) && empty($localizationOptionsInstall))
		{
			echo json_encode(array('error' => false, 'installed' => 'nothing'));
			jexit(42);
		}

		/** @var CInstallerModelInstall $model */
		$model = JModelLegacy::getInstance('Install', 'CInstallerModel');

		$product = $model->getProduct($product);

		$product->installSampleData($sampleDataInstall);
		$product->setLocalizationOption($localizationOptionsInstall);

		echo json_encode(array('error' => false, 'installed' => 'all'));
		jexit(0);
	}

	/**
	 * Download and install package
	 *
	 * @param   string  $url The URL
	 *
	 * @return  bool
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	private function downloadPackage($url)
	{
		$path = JInstallerHelper::downloadPackage($url);

		$path = JPATH_ROOT . '/tmp/' . basename($path);

		$package = JInstallerHelper::unpack($path, true);

		if ($package['type'] === false)
		{
			return false;
		}

		$jInstaller = JInstaller::getInstance();
		$result     = $jInstaller->install($package['extractdir']);
		JInstallerHelper::cleanupInstall($path, $package['extractdir']);

		return $result;
	}

	/**
	 * Install local package
	 *
	 * @param   string  $path  Path to the local package
	 *
	 * @return  bool
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function installLocalPackage($path)
	{
		$package = JInstallerHelper::unpack($path, true);

		if ($package['type'] === false)
		{
			return false;
		}

		$jInstaller = JInstaller::getInstance();
		$result     = $jInstaller->install($package['extractdir']);
		JInstallerHelper::cleanupInstall($path, $package['extractdir']);

		return $result;
	}

	/**
	 * Cleanup and redirect
	 *
	 * @return  void
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function finish()
	{
		$input = JFactory::getApplication()->input;

		/** @var CInstallerModelInstall $model */
		$model = JModelLegacy::getInstance('Install', 'CInstallerModel');

		$product = $input->get('product', null);

		if (empty($product))
		{
			echo json_encode(array('error' => true, 'message' => 'No product given'));
			jexit(42);
		}

		$product = $model->getProduct($product);

		$link = JRoute::_('index.php?option=' . $product->getComponentIdentifier());
		$msg  = JText::_('COM_CINSTALLER_INSTALLATION_SUCCESSFULLY_FINISHED');

		// Don't remove installer

		$this->setRedirect($link, $msg);
	}

	/**
	 * Get the Extension Id of the Installer
	 *
	 * @return  mixed
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	private function getExtensionId()
	{
		$db = JFactory::getDbo();

		$query = $db->getQuery(true);

		$query
			->select('extension_id')
			->from('#__extensions')
			->where('element = ' . $db->quote('com_cinstaller'));

		$db->setQuery($query);

		return $db->loadResult();
	}
}
