<?php

defined('_JEXEC') or die;

/**
 * Interface CProductInterface
 *
 * @since  1.0.0
 */
interface CProductInterface
{
	/**
	 * Get the extension name
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public function getExtensionName();

	/**
	 * Get the product icon (fa or image)
	 *
	 * @return  mixed
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function getIcon();

	/**
	 * Get the component name (e.g. com_matukio)
	 *
	 * @return  string
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function getComponentIdentifier();

	/**
	 * Get the update Server URL (we use this to get the latest version)
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public function getUpdateServer();

	/**
	 * Does the extension need a download id
	 *
	 * @return  boolean
	 *
	 * @since   1.0.0
	 */
	public function needsDownloadId();

	/**
	 * Get the extension name
	 *
	 * @param   CInstallerRequirements  $defaultRequirements  The default requirements
	 *
	 * @return  CInstallerRequirements
	 *
	 * @since   1.0.0
	 */
	public function getRequirements();

	/**
	 * Get the redirect URL string
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public function getRedirectUrl();

	/**
	 * Get the ARS category id
	 *
	 * @return  int
	 *
	 * @since   1.0.0
	 */
	public function getArsCategory();

	/**
	 * Get the sample data
	 *
	 * @return  array
	 *
	 * @since   1.0.0
	 */
	public function getSampleData();

	/**
	 * Get the localization options
	 *
	 * @return  array
	 *
	 * @since   1.0.0
	 */
	public function getLocalizationOptions();

	/**
	 * Install the sample data
	 *
	 * @param   string  $target  The data to install
	 *
	 * @return  boolean
	 *
	 * @since   1.0.0
	 */
	public function installSampleData($target);

	/**
	 * Install and set the localization data
	 *
	 * @param   string  $target  The localization to install
	 *
	 * @return  boolean
	 *
	 * @since   1.0.0
	 */
	public function setLocalizationOption($target);

	/**
	 * Get the youtube video shown at the last page of the install
	 *
	 * @return  string
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function getYoutubeVideo();

	/**
	 * Is it a top / featured product?
	 *
	 * @return  boolean
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function isTopProduct();
}
