<?php

defined('_JEXEC') or die;

require_once __DIR__ . '/interface.php';
require_once __DIR__ . '/requirements.php';

/**
 * Class CProduct
 *
 * @since  1.0.0
 */
abstract class CProduct implements CProductInterface
{
	/**
	 * Does the extension require a download Id
	 *
	 * @return  bool
	 *
	 * @since   1.0.0
	 */
	public function needsDownloadId()
	{
		return true;
	}

	/**
	 * Install the sample data
	 *
	 * @param   string  $target  The data to install
	 *
	 * @return  boolean
	 *
	 * @since   1.0.0
	 */
	public function installSampleData($target)
	{
		// Path to the sample files
		$basePath = JPATH_ADMINISTRATOR . '/components/' . $this->getComponentIdentifier() . '/sql/sample/';

		foreach ($this->getSampleData() as $sample)
		{
			if ($sample['name'] != $target)
			{
				continue;
			}

			$sql = $sample['sql'];

			if (empty($sql))
			{
				return true;
			}

			$file = $basePath . $sql;

			if (!JFile::exists($file))
			{
				JFactory::getApplication()->enqueueMessage('Sample data file ' . $file . ' not found', 'warning');

				return true;
			}

			$db = JFactory::getDbo();

			$contents = file_get_contents($file);

			$queries = $db->splitSql($contents);

			foreach ($queries as $query)
			{
				$db->setQuery($query);

				$success = $db->execute();
			}
		}

		return true;
	}

	/**
	 * Install and set the localization data
	 *
	 * @param   string  $target  The localization to install
	 *
	 * @return  boolean
	 *
	 * @since   1.0.0
	 */
	public function setLocalizationOption($target)
	{
		$localization = null;

		foreach ($this->getLocalizationOptions() as $option)
		{
			if ($option['name'] == $target)
			{
				$localization = $option;
				break;
			}
		}

		if (empty($localization))
		{
			return true;
		}

		// Update the configuration
		$this->updateConfigLocalization($localization['settings']);

		// Execute the update SQL
		$this->executeSqlLocalization($localization['sql']);
	}

	/**
	 * Update the config.xml of the extension
	 *
	 * @param   array  $settings  Settings to install
	 *
	 * @return  bool
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	protected function updateConfigLocalization($settings)
	{
		if (empty($settings))
		{
			return true;
		}

		// Update config file
		jimport('joomla.application.component.helper');

		$params = JComponentHelper::getParams($this->getComponentIdentifier());

		foreach ($settings as $key => $value)
		{
			$params->set($key, $value);
		}

		// Libary should be installed
		JLoader::register('CompojoomComponentHelper', JPATH_ROOT . '/libraries/compojoom/installer/installer.php', true);
		CompojoomComponentHelper::updateConfiguration("com_matukio", json_encode($params));

		return true;
	}

	/**
	 * Execute an SQL file
	 *
	 * @param   string  $sqlFile  File to execute
	 *
	 * @return  bool
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	protected function executeSqlLocalization($sqlFile)
	{
		if (empty($sqlFile))
		{
			return true;
		}

		$basePath = JPATH_ADMINISTRATOR . '/components/' . $this->getComponentIdentifier() . '/sql/localization/';

		$file = $basePath . $sqlFile;

		if (!JFile::exists($file))
		{
			JFactory::getApplication()->enqueueMessage('Localization data file ' . $file . ' not found', 'warning');

			return true;
		}

		$db = JFactory::getDbo();

		$contents = file_get_contents($file);

		if (empty($contents))
		{
			return true;
		}

		$queries = $db->splitSql($contents);

		foreach ($queries as $query)
		{
			$db->setQuery($query);

			$db->execute();
		}
	}
}
