<?php

defined('_JEXEC') or die;

/**
 * Class MatukioProduct
 *
 * @since  1.0.0
 */
class MatukioProduct extends CProduct
{
	/**
	 * Get the extension name
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public function getExtensionName()
	{
		return 'Matukio Events';
	}

	/**
	 * Get the product icon (fa or image)
	 *
	 * @return  mixed
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function getIcon()
	{
		return 'media/com_cinstaller/images/extensions/matukio.png';
	}

	/**
	 * Get the component name (e.g. com_matukio)
	 *
	 * @return  string
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function getComponentIdentifier()
	{
		return 'com_matukio';
	}

	/**
	 * Get the update Server URL (we use this to get the latest version)
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public function getUpdateServer()
	{
		return 'https://compojoom.com/index.php?option=com_ars&view=update&task=stream&format=xml&id=9&dummy=extension.xml';
	}

	/**
	 * Get the extension name
	 *
	 * @param   CInstallerRequirements  $defaultRequirements  The default requirements
	 *
	 * @return  CInstallerRequirements
	 *
	 * @since   1.0.0
	 */
	public function getRequirements()
	{
		$requirements = new CInstallerRequirements();

		$requirements->set('phpMin', '5.5.39');
		$requirements->set('phpCurl', '7.0.34');

		return $requirements;
	}

	/**
	 * Get the redirect URL string
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	public function getRedirectUrl()
	{
		return 'index.php?option=com_matukio';
	}

	/**
	 * Get the sample data
	 *
	 * @return  array
	 *
	 * @since   1.0.0
	 */
	public function getSampleData()
	{
		return [
			[
				'name' => 'none',
				'sql' => ''
			],
			[
				'name' => 'one_event',
				'sql' => 'one_event.sql'
			],
			[
				'name' => 'demo',
				'sql'  => 'demo.sql'
			]
		];
	}

	/**
	 * Get the localization options
	 *
	 * @return  array
	 *
	 * @since   1.0.0
	 */
	public function getLocalizationOptions()
	{
		return [
			[
				'name' => 'default',
				'settings' => [],
				'sql' => ''
			],
			[
				'name' => 'us',
				'settings' => [
					'participant_gradin_kind' => 'american',
					'date_format' => 'F d, Y h:i a',
					'date_format_small' => 'm/d/Y h:i a',
					'date_format_without_time' => 'm/d/Y',
					'long_date_format_without_time' => 'F d, Y',
					'time_format' => 'h:i a',
					'gmap_default_center' => '37.090240,-95.712891',
					'mat_signature' => '<strong>This is an automatically generated email, please do not reply</strong>',
					'dezimal_stellen' => '2',
					'csv_export_charset' => 'UTF-8',
					'export_csv_separator' => ',',
					'export_csv_delimiter' => '"',
					'distance_unit' => 'miles',
					'localization' => 'us',
					'migrated7' => 1,
				],
				'sql' => 'us.sql'
			],
			[
				'name' => 'uk',
				'settings' => [
					'participant_gradin_kind' => 'american',
					'date_format' => 'd F Y H:i a',
					'date_format_small' => 'd/m/Y h:i a',
					'date_format_without_time' => 'd/m/Y',
					'long_date_format_without_time' => 'd F Y',
					'time_format' => 'h:i a',
					'gmap_default_center' => '51.507351,-0.127758',
					'mat_signature' => '<strong>This is an automatically generated email, please do not reply</strong>',
					'dezimal_stellen' => '2',
					'csv_export_charset' => 'UTF-8',
					'export_csv_separator' => ',',
					'export_csv_delimiter' => '"',
					'distance_unit' => 'miles',
					'localization' => 'uk',
					'migrated7' => 1,
				],
				'sql' => 'uk.sql'
			],
			[
				'name' => 'germany',
				'settings' => [
					'participant_gradin_kind' => 'european',
					'date_format' => 'l d.M.Y H:i',
					'date_format_small' => 'd.m.Y H:i',
					'date_format_without_time' => 'd.m.Y',
					'long_date_format_without_time' => 'l, d. F Y',
					'time_format' => 'H:i',
					'gmap_default_center' => '52.520007,13.404954',
					'mat_signature' => '<strong>Dies ist eine automatisch generierte E-Mail, bitte antworten Sie nicht</strong>',
					'dezimal_stellen' => '2',
					'csv_export_charset' => 'ISO-8859-1',
					'export_csv_separator' => ';',
					'export_csv_delimiter' => '\'',
					'distance_unit' => 'km',
					'localization' => 'germany',
					'migrated7' => 1,
				],
				'sql' => 'germany.sql'
			],
		];
	}

	/**
	 * Get the ARS category id
	 *
	 * @return  int
	 *
	 * @since   1.0.0
	 */
	public function getArsCategory()
	{
		return 10;
	}

	/**
	 * Get the youtube video shown at the last page of the install
	 *
	 * @return  string
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function getYoutubeVideo()
	{
		return '6fZAdVln0Fg';
	}

	/**
	 * Is it a top / featured product?
	 *
	 * @return  boolean
	 *
	 * @since   __DEPLOY_VERSION__
	 */
	public function isTopProduct()
	{
		return true;
	}
}
