<?php

defined('_JEXEC') or die;

/**
 * Class Requirement
 *
 * @since   1.0.0
 */
class Requirement
{
	/**
	 * Name of the requirement, also used for languages and method names
	 *
	 * @var    string
	 *
	 * @since  1.0.0
	 */
	public $name;

	/**
	 * Target version(s) of the requirement
	 *
	 * @var    string|array
	 *
	 * @since  1.0.0
	 */
	public $target;


	/**
	 * Is the requirement required to be fullfilled
	 *
	 * @var    boolean
	 *
	 * @since  1.0.0
	 */
	public $isRequired;

	/**
	 * Is the requirement required to be fullfilled
	 *
	 * @var    boolean
	 *
	 * @since  1.0.0
	 */
	public $isFullfilled = true;

	/**
	 * The current live version(s) of the requirement
	 *
	 * @var    string|array
	 *
	 * @since  1.0.0
	 */
	public $currentVersion;

	/**
	 * Requirement constructor.
	 *
	 * @param   string        $name        Name of the requirement (used for translation)
	 * @param   string|array  $target      Target version
	 * @param   bool          $isRequired  Is it required to install
	 *
	 * @since  1.0.0
	 */
	private function __construct($name, $target, $isRequired)
	{
		$this->name       = $name;
		$this->target     = $target;
		$this->isRequired = $isRequired;
	}

	/**
	 * Factory for creating an instance
	 *
	 * @param   string        $name        Name of the requirement (used for translation)
	 * @param   string|array  $target      Target version
	 * @param   bool          $isRequired  Is it required to install
	 *
	 * @return  Requirement
	 *
	 * @since   1.0.0
	 */
	public static function create($name, $target, $isRequired = true)
	{
		return new Requirement($name, $target, $isRequired);
	}
}
