<?php

defined('_JEXEC') or die;

/**
 * Installation class to perform additional changes during install/uninstall/update
 *
 * @since  1.0.0
 */
class Com_CInstallerInstallerScript
{
	/**
	 * The release version
	 *
	 * @var     string
	 * @since   1.0.0
	 */
	protected $release = '1.0.2';

	/**
	 * Extension
	 *
	 * @var     string
	 * @since   1.0.0
	 */
	protected $extension = 'com_cinstaller';

	/**
	 * Modules, Plugins, Libraries etc. to install
	 *
	 * @var     array
	 * @since   1.0.0
	 */
	protected $installationQueue = array(
		// Key is the name without the lib_ prefix, value if the library should be autopublished
		'libraries' => array(
			'compojoom' => 1
		)
	);

	/**
	 * The compojoom installer
	 *
	 * @var      CompojoomInstaller
	 * @since    1.0.0
	 */
	protected $installer;

	/**
	 * Executed on install/update/discover
	 *
	 * @param   string                      $type    - the type of the installation
	 * @param   JInstallerAdapterComponent  $parent  - the parent JInstaller obeject
	 *
	 * @throws  Exception  - if library is not found
	 *
	 * @return  boolean - true if everything is OK and we should continue with the installation
	 *
	 * @since   1.0.0
	 */
	public function preflight($type, $parent)
	{
		$path = $parent->getParent()->getPath('source') . '/libraries/compojoom/include.php';

		// Check if the file exists (on discover install it won't)
		if (JFile::exists($path))
		{
			require_once $path;
		}
		else
		{
			// Try fallback to installed one
			$path = JPATH_ROOT . '/libraries/compojoom/include.php';

			if (JFile::exists($path))
			{
				require_once $path;
			}
			else
			{
				throw new Exception("Compojoom library not found", 404);
			}
		}

		$this->installer = new CompojoomInstaller($type, $parent, $this->extension);

		if (!$this->installer->allowedInstall())
		{
			return false;
		}

		return true;
	}


	/**
	 * Method to uninstall the component
	 *
	 * @param   object  $parent  - the parent object
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	public function uninstall($parent)
	{
		require_once JPATH_LIBRARIES . '/compojoom/include.php';

		$this->installer = new CompojoomInstaller('uninstall', $parent, $this->extension);
		$this->status = new stdClass;

		echo $this->displayInfoUninstallation();
	}

	/**
	 * Method to run after the install routine.
	 *
	 * @param   string                      $type    The action being performed
	 * @param   JInstallerAdapterComponent  $parent  The class calling this method
	 *
	 * @return  void
	 *
	 * @since   1.0.0
	 */
	public function postflight($type, $parent)
	{
		// Install Lib compojoom, we need that
		$this->installer->installLibraries($this->installationQueue['libraries']);

		// Redirect to real installer
		JFactory::getApplication()->redirect('index.php?option=com_cinstaller');
		jexit(1);
	}

	/**
	 * Displays uninstall info
	 *
	 * @return  string
	 *
	 * @since   1.0.0
	 */
	protected function displayInfoUninstallation()
	{
		$html[] = CompojoomHtmlTemplates::renderSocialMediaInfo();

		return implode('', $html);
	}
}
